@@ -1,21 +1,21 @@
-from functools import partial
+from functools import partial, wraps
 from itertools import izip_longest
 
 
-__all__ = ['chunked', 'first', 'peekable', 'collate']
+__all__ = ['chunked', 'first', 'peekable', 'collate', 'consumer']
 
 
 _marker = object()
 
 
 def chunked(iterable, n):
-    """Break an iterable into tuples of a given length::
+    """Break an iterable into lists of a given length::
 
         >>> list(chunked([1, 2, 3, 4, 5, 6, 7], 3))
-        [(1, 2, 3), (4, 5, 6), (7,)]
+        [[1, 2, 3], [4, 5, 6], [7]]
 
     If the length of ``iterable`` is not evenly divisible by ``n``, the last
-    returned tuple will be shorter.
+    returned list will be shorter.
 
     This is useful for splitting up a computation on a large number of keys
     into batches, to be pickled and sent off to worker processes. One example
@@ -25,10 +25,11 @@ def chunked(iterable, n):
 
     """
     # Doesn't seem to run into any number-of-args limits.
-    for group in izip_longest(*[iter(iterable)] * n, fillvalue=_marker):
+    for group in (list(g) for g in izip_longest(*[iter(iterable)] * n,
+                                                fillvalue=_marker)):
         if group[-1] is _marker:
             # If this is the last group, shuck off the padding:
-            group = tuple(x for x in group if x is not _marker)
+            del group[group.index(_marker):]
         yield group
 
 
@@ -118,8 +119,6 @@ class peekable(object):
         provided, raise ``StopIteration``.
 
         """
-        # TODO: Give peek a default arg. Raise StopIteration only when it isn't
-        # provided. If it is, return the arg. Just like get('key', object())
         if not hasattr(self, '_peek'):
             try:
                 self._peek = self._it.next()
@@ -164,3 +163,33 @@ def collate(*iterables, **kwargs):
         _, p = min_or_max((key(p.peek()), p) for p in peekables)
         yield p.next()
         peekables = [p for p in peekables if p]
+
+
+def consumer(func):
+    """Decorator that automatically advances a PEP-342-style "reverse iterator"
+    to its first yield point so you don't have to call ``next()`` on it
+    manually.
+
+    >>> @consumer
+    ... def tally():
+    ...     i = 0
+    ...     while True:
+    ...         print 'Thing number %s is %s.' % (i, (yield))
+    ...         i += 1
+    ...
+    >>> t = tally()
+    >>> t.send('red')
+    Thing number 0 is red.
+    >>> t.send('fish')
+    Thing number 1 is fish.
+
+    Without the decorator, you would have to call ``t.next()`` before
+    ``t.send()`` could be used.
+
+    """
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+        gen = func(*args, **kwargs)
+        gen.next()
+        return gen
+    return wrapper
