@@ -44,14 +44,14 @@ class ChunkedTests(TestCase):
 
     def test_even(self):
         """Test when ``n`` divides evenly into the length of the iterable."""
-        eq_(list(chunked('ABCDEF', 3)), [('A', 'B', 'C'), ('D', 'E', 'F')])
+        eq_(list(chunked('ABCDEF', 3)), [['A', 'B', 'C'], ['D', 'E', 'F']])
 
     def test_odd(self):
         """Test when ``n`` does not divide evenly into the length of the
         iterable.
 
         """
-        eq_(list(chunked('ABCDE', 3)), [('A', 'B', 'C'), ('D', 'E')])
+        eq_(list(chunked('ABCDE', 3)), [['A', 'B', 'C'], ['D', 'E']])
 
 
 class FirstTests(TestCase):
@@ -78,16 +78,9 @@ class FirstTests(TestCase):
 
 class PeekableTests(TestCase):
     """Tests for ``peekable()`` behavor not incidentally covered by testing
-    ``collate``
+    ``collate()``
 
     """
-    def test_import(self):
-        """``peekable`` is incidentally covered by ``CollateTests``, but make
-        sure the symbol is imported by ``import *``.
-
-        """
-        peekable
-
     def test_peek_default(self):
         """Make sure passing a default into ``peek()`` works."""
         p = peekable([])
@@ -102,3 +95,26 @@ class PeekableTests(TestCase):
         self.failIf(p)
         p = peekable(xrange(3))
         self.failUnless(p)
+
+    def test_simple_peeking(self):
+        """Make sure ``next`` and ``peek`` advance and don't advance the
+        iterator, respectively.
+
+        """
+        p = peekable(xrange(10))
+        eq_(p.next(), 0)
+        eq_(p.peek(), 1)
+        eq_(p.next(), 1)
+
+
+class ConsumerTests(TestCase):
+    """Tests for ``consumer()``"""
+
+    def test_consumer(self):
+        @consumer
+        def eater():
+            while True:
+                x = yield
+        
+        e = eater()
+        e.send('hi')  # without @consumer, would raise TypeError
